==> opm_0.2-1.tar.gz: opm/man/OPMX.Rd <==
\docType{class}
\name{OPMX}
\alias{OPMX}
\title{OPMX class}
\description{
  This is a virtual class containing helper methods for
  plotting \code{\link{OPM}} and \code{\link{OPMS}}
  objects. It is not directly applied by an \pkg{opm} user.
  Regarding the name: \sQuote{OPMX} stands for \sQuote{OPM
  or OPMS}.
}
\seealso{
  Methods

  Other classes: \code{\link{OPM}}, \code{\link{OPMA}},
  \code{\link{OPMS}}, \code{\link{WMD}},
  \code{\link{YAML_VIA_LIST}}
}
\keyword{methods}

% \name{OPMX-class}
\Rdversion{1.1}
% \docType{class}
\alias{OPMX-class}
% \alias{c,OPMX-method}
% \alias{improved_max,OPMX-method}
% \alias{main_title,OPMX-method}
% \alias{negative_control,OPMX-method}

% \title{Class \code{"OPMX"}}
% \description{
% %%  ~~ A concise (1-5 lines) description of what the class is. ~~
% }
\section{Objects from the Class}{A virtual Class: No objects may be created from it.}
\section{Methods}{
  \describe{
    \item{c}{\code{signature(x = "OPMX")}: ... }
    \item{improved_max}{\code{signature(object = "OPMX")}: ... }
    \item{main_title}{\code{signature(object = "OPMX")}: ... }
    \item{negative_control}{\code{signature(object = "OPMX")}: ... }
	 }
}
% \references{
% %%  ~~put references to the literature/web site here~~
% }
% \author{
% %%  ~~who you are~~
% }
% \note{
% %%  ~~further notes~~
% }

%% ~Make other sections like Warning with \section{Warning }{....} ~

% \seealso{
% %%  ~~objects to See Also as \code{\link{~~fun~~}}, ~~~
% %%  ~~or \code{\linkS4class{CLASSNAME}} for links to other classes ~~~
% }
\examples{
showClass("OPMX")
}
\keyword{classes}

==> opm_0.4-0.tar.gz: opm/man/OPMX.Rd <==
\docType{class}
\name{OPMX}
\alias{OPMX}
\title{OPMX class}
\description{
  This is a virtual class containing helper methods for
  plotting \code{\link{OPM}} and \code{\link{OPMS}}
  objects. It is not directly applied by an \pkg{opm} user.
  Regarding the name: \sQuote{OPMX} stands for \sQuote{OPM
  or OPMS}.
}
\seealso{
  Methods

  Other classes: \code{\link{MOA}}, \code{\link{OPM}},
  \code{\link{OPMA}}, \code{\link{OPMS}},
  \code{\link{WMD}}, \code{\link{YAML_VIA_LIST}}
}
\keyword{methods}

% \name{OPMX-class}
\Rdversion{1.1}
% \docType{class}
\alias{OPMX-class}
% \alias{c,OPMX-method}
% \alias{improved_max,OPMX-method}
% \alias{main_title,OPMX-method}
% \alias{negative_control,OPMX-method}

% \title{Class \code{"OPMX"}}
% \description{
% %%  ~~ A concise (1-5 lines) description of what the class is. ~~
% }
\section{Objects from the Class}{A virtual Class: No objects may be created from it.}
\section{Methods}{
  \describe{
    \item{c}{\code{signature(x = "OPMX")}: ... }
    \item{improved_max}{\code{signature(object = "OPMX")}: ... }
    \item{main_title}{\code{signature(object = "OPMX")}: ... }
    \item{negative_control}{\code{signature(object = "OPMX")}: ... }
	 }
}
% \references{
% %%  ~~put references to the literature/web site here~~
% }
% \author{
% %%  ~~who you are~~
% }
% \note{
% %%  ~~further notes~~
% }

%% ~Make other sections like Warning with \section{Warning }{....} ~

% \seealso{
% %%  ~~objects to See Also as \code{\link{~~fun~~}}, ~~~
% %%  ~~or \code{\linkS4class{CLASSNAME}} for links to other classes ~~~
% }
\examples{
showClass("OPMX")
}
\keyword{classes}
